.. factored documentation master file, created by
   sphinx-quickstart on Thu Apr 17 14:36:08 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to factored's documentation!
====================================

Factored is a comprehensive 2-factor authentication system that works with
any web technology.


Contents:

.. toctree::
   :maxdepth: 2

   about
   install
   config
   users
   webserverplugins


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

